SystemOrganization addCategory: #IconsBase!

Object subclass: #UiIcons
	instanceVariableNames: ''
	classVariableNames: 'Icons'
	poolDictionaries: ''
	category: 'IconsBase'!

!UiIcons class methodsFor: 'caching' stamp: 'pre 2/21/2018 10:38'!
cachePrefix

	^ self subclassResponsibility! !

!UiIcons class methodsFor: 'as yet unclassified' stamp: 'mt 2/21/2013 10:12:05.67'!
detect: aForm

	^ self
		detect: aForm
		ifNone: [self error: 'Icon is not in the library.']! !

!UiIcons class methodsFor: 'as yet unclassified' stamp: 'mt 2/21/2013 10:10:06.071'!
detect: aForm ifNone: aBlock
	"Looks for a method reference that returns the given form."
	
	self subclassesDo: [:cls |
		(cls theMetaClass organization listAtCategoryNamed: 'accessing') do: [:selector | (cls perform: selector) == aForm ifTrue: [^ MethodReference class: cls theMetaClass selector: selector]]].
	
	^ aBlock value
	! !

!UiIcons class methodsFor: 'file reader services' stamp: 'pre 2/21/2018 16:31'!
fileInSingleIcon: fullName

	| iconClass categoryName categories |
	iconClass := UIManager default 
		chooseFrom: (UiIcons allSubclasses collect: [:cls | cls name]) 
		values: UiIcons allSubclasses
		title: 'Choose class in which the icon should be stored'.
	iconClass ifNil: [^ self].
		
	categories := iconClass class organization categories collect: [:each | (each findTokens: '-') first ].
	categories := categories asSet asArray.
	categoryName := UIManager default
		chooseFromOrAddTo: categories
		lines: #()
		title: 'Under which category should the icon be stored?'.
	categoryName ifNil: [^ self].
		
	iconClass loadFromFileNamed: fullName into: categoryName.
		
	! !

!UiIcons class methodsFor: 'file reader services' stamp: 'pre 2/21/2018 16:15'!
fileReaderServicesForFile: fullName suffix: suffix
	"Answer services for the given file"

	suffix = 'png' ifFalse: [^ #()].	
		
	^ {SimpleServiceEntry 
		provider: self 
		label: 'filein as icon'
		selector: #fileInSingleIcon:
		description: 'import the graphics as an icon'
		buttonLabel: 'filein as icon'}! !

!UiIcons class methodsFor: 'class initialization' stamp: 'pre 2/21/2018 16:04'!
initialize


	self initializeIcons.
	Smalltalk addToStartUpList: self.
	FileServices registerFileReader: self.! !

!UiIcons class methodsFor: 'class initialization' stamp: 'mt 7/2/2010 08:07:15.636'!
initializeIcons

	| methods |
	Icons := IdentityDictionary new.
	methods := self class selectors
				select: [:each | '*Icon' match: each asString].
	methods
		do: [:each | Icons
				at: each
				put: (self perform: each)].! !

!UiIcons class methodsFor: 'license' stamp: 'mt 7/2/2010 08:10:09.996'!
license

	self subclassResponsibility.! !

!UiIcons class methodsFor: 'bulk loading' stamp: 'pre 12/20/2017 18:46'!
loadFrom: aPath

	^ self loadFrom: aPath into: ''! !

!UiIcons class methodsFor: 'bulk loading' stamp: 'pre 2/21/2018 16:20'!
loadFrom: aPath into: categoryPrefix

	((FileDirectory on: aPath) fileNames 
		select: [:fileName | (fileName last: (4 min: fileName size)) asLowercase = '.png'])
			do: [:fileName |	self loadFromFileNamed: fileName into: categoryPrefix] 
			displayingProgress: [:fileName | 'Loading ', fileName, '...'].! !

!UiIcons class methodsFor: 'bulk loading' stamp: 'pre 2/21/2018 16:22'!
loadFromFileNamed: aFilePath into: categoryPrefix

	| accessorTemplate contentsTemplate tokens selector fileName filePath |
	accessorTemplate := '{2}Icon
	"Auto-generated.
	{3}"
	^ Icons at: #{4}{1}
	ifAbsentPut:[ Form fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self {2}IconContents readStream) ].'.
	contentsTemplate := '{1}IconContents
	"Auto-generated.
	{3}"
	^ ''{2}'''.
	
	filePath := FileDirectory on: aFilePath.
	fileName := filePath localName.
	
	tokens := ((fileName allButLast: 4) copyWithoutAll: '._-+~:#') findTokens: $-.
	selector := tokens inject: '' into: [:all :each | all, each capitalized].
	selector first isDigit ifTrue: [selector := 'i' , selector].
	
	self class
		compile: (contentsTemplate format: {selector withFirstCharacterDownshifted. (MenuIcons base64ContentsOfFileNamed: aFilePath). self license})
		classified: categoryPrefix , (categoryPrefix ifNotEmpty: ['-'] ifEmpty: ['']) , 'contents';
		compile: (accessorTemplate format: {selector capitalized. selector withFirstCharacterDownshifted. self license . self cachePrefix})
		classified: categoryPrefix , (categoryPrefix ifNotEmpty: ['-'] ifEmpty: ['']) , 'accessing'.! !

!UiIcons class methodsFor: 'caching' stamp: 'pre 2/21/2018 14:36'!
resetCache

	self resetCacheFor: self cachePrefix! !

!UiIcons class methodsFor: 'caching' stamp: 'pre 12/27/2017 12:20'!
resetCacheFor: prefix

	Icons keysAndValuesRemove: [:key :value | key beginsWith: prefix] ! !

!UiIcons class methodsFor: 'class initialization' stamp: 'pre 2/21/2018 16:05'!
unload

	FileServices unregisterFileReader: self. 
	Smalltalk removeFromStartUpList: self.! !
UiIcons initialize!
